AXIOM nMigen Gateware
=====================

.. warning::
   This manual is a work in progress and is seriously incomplete!

Building Blocks & FPGA Designs powering the AXIOM micro camera written in Python & `nMigen <https://github.com/nmigen/nmigen>`__.
Mostly a place to experiment and figure out how to build things.

.. toctree::
   :maxdepth: 10
   :caption: Contents:

   intro
   installation
   modules
